"""ESPHome dashboard."""
from pathlib import Path
import json


def where():
    """Return path to the frontend."""
    return Path(__file__).parent

def entrypoint():
    manifest = json.loads((where() / "static/js/esphome/manifest.json").read_text())
    return manifest['index']



from setuptools import setup, find_packages

setup(
    name="esphome-dashboard",
    version="20230117.0",
    description="ESPHome dashboard",
    url="https://github.com/esphome/dashboard",
    author="Nabu Casa",
    author_email="hello@nabucasa.com",
    license="Apache-2.0",
    packages=find_packages(include=["esphome_dashboard", "esphome_dashboard.*"]),
    include_package_data=True,
    zip_safe=False,
)
